Stan Math Library: stan/math/fwd/scal/fun/rising_factorial.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

rising_factorial.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_RISING_FACTORIAL_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_RISING_FACTORIAL_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <stan/math/prim/scal/fun/rising_factorial.hpp>
6 #include <stan/math/prim/scal/fun/digamma.hpp>
7 #include <iostream>
8
9 namespace stan {
10
11 namespace math {
12
13 template<typename T>
14 inline
15 fvar<T>
16 rising_factorial(const fvar<T>& x, const fvar<T>& n) {
17 using stan::math::rising_factorial;
18
19 T rising_fact(rising_factorial(x.val_, n.val_));
20 return fvar<T>(rising_fact,
21 rising_fact * (digamma(x.val_ + n.val_)
22 * (x.d_ + n.d_) - digamma(x.val_) * x.d_));
23 }
24
25 template<typename T>
26 inline
27 fvar<T>
28 rising_factorial(const fvar<T>& x, const double n) {
29 using stan::math::rising_factorial;
30 using boost::math::digamma;
31
32 T rising_fact(rising_factorial(x.val_, n));
33 return fvar<T>(rising_fact,
34 rising_fact * x.d_
35 * (digamma(x.val_ + n) - digamma(x.val_)));
36 }
37
38 template<typename T>
39 inline
40 fvar<T>
41 rising_factorial(const double x, const fvar<T>& n) {
42 using stan::math::rising_factorial;
43 using boost::math::digamma;
44
45 T rising_fact(rising_factorial(x, n.val_));
46 return fvar<T>(rising_fact,
47 rising_fact * (digamma(x + n.val_) * n.d_));
48 }
49 }
50 }
51 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
digamma.hpp
rising_factorial.hpp
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::rising_factorial
fvar< T > rising_factorial(const fvar< T > &x, const fvar< T > &n)
Definition: rising_factorial.hpp:16
stan::math::fvar
Definition: fvar.hpp:13
stan::math::digamma
fvar< T > digamma(const fvar< T > &x)
Definition: digamma.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.